@@ -4,12 +4,16 @@ mod say;
 mod sudo;
 mod ctid;
 mod urbandict;
+mod corona;
+mod ipinfo;
 
 use help::perocmd_help;
 use say::perocmd_say;
 use sudo::{ pero_sudocmd_sh, pero_sudocmd_upload };
 use ctid::perocmd_ctid;
 use urbandict::perocmd_udi;
+use corona::perocmd_cs;
+use ipinfo::perocmd_ipi;
 
 use teloxide::prelude::*;
 use teloxide::types::ParseMode::Html;
@@ -28,6 +32,8 @@ pub enum Command {
     Udi { term: String },
     #[command(prefix = "p.")]
     Upload { file: String },
+    Cs { ctry: String },
+    Ipi { ip: String },
 }
 
 #[allow(unreachable_patterns)]
@@ -41,6 +47,8 @@ pub async fn answer(cx: UpdateWithCx<AutoSend<Bot>, Message>, command: Command)
         Command::Ctid => perocmd_ctid(cx).await,
         Command::Udi { term } => perocmd_udi(cx, term).await,
         Command::Upload { file } => pero_sudocmd_upload(cx, file).await,
+        Command::Cs { ctry } => perocmd_cs(cx, ctry).await,
+        Command::Ipi { ip } => perocmd_ipi(cx, ip).await,
     };
 
     Ok(())
